@@ -20,7 +20,7 @@ subparsers = parser.add_subparsers(title="Tutum's CLI commands", dest='cmd')
 
 
 # Command Parsers
-parsers.add_app_parser(subparsers)
+parsers.add_cluster_parser(subparsers)
 parsers.add_build_parser(subparsers)
 parsers.add_container_parser(subparsers)
 parsers.add_image_parser(subparsers)
@@ -30,13 +30,14 @@ parsers.add_login_parser(subparsers)
 def main():
     if len(sys.argv) == 1:
         sys.argv.append('-h')
-    elif len(sys.argv) == 2 and sys.argv[1] in ['app', 'build', 'container', 'image', ]:
+    elif len(sys.argv) == 2 and sys.argv[1] in ['cluster', 'build', 'container', 'image', ]:
         sys.argv.append('-h')
     elif len(sys.argv) == 3:
-        if sys.argv[1] == 'app' and sys.argv[2] in ['alias', 'inspect', 'logs', 'redeploy', 'run', 'scale', 'set',
+        if sys.argv[1] == 'cluster' and sys.argv[2] in ['alias', 'inspect', 'logs', 'redeploy', 'run', 'scale', 'set',
                                                     'start', 'stop', 'terminate']:
             sys.argv.append('-h')
-        elif sys.argv[1] == 'container' and sys.argv[2] in ['inspect', 'logs', 'start', 'stop', 'terminate']:
+        elif sys.argv[1] == 'container' and sys.argv[2] in ['inspect', 'logs', 'redeploy', 'run', 'start', 'stop',
+                                                            'terminate']:
             sys.argv.append('-h')
         elif sys.argv[1] == 'image' and sys.argv[2] in ['register', 'push', 'rm', 'search', 'update']:
             sys.argv.append('-h')
@@ -50,36 +51,37 @@ def main():
         commands.login()
     if args.cmd == 'build':
         commands.build(args.tag, args.directory, args.quiet, args.no_cache)
-    elif args.cmd == 'app':
+    elif args.cmd == 'cluster':
         if args.subcmd == 'alias':
-            commands.app_alias(args.identifier, args.dns)
+            commands.cluster_alias(args.identifier, args.dns)
         elif args.subcmd == 'inspect':
-            commands.app_inspect(args.identifier)
+            commands.cluster_inspect(args.identifier)
         elif args.subcmd == 'logs':
-            commands.app_logs(args.identifier)
+            commands.cluster_logs(args.identifier)
         elif args.subcmd == 'open':
-            commands.app_open()
+            commands.cluster_open()
         elif args.subcmd == 'ps':
-            commands.app_ps(args.quiet, args.status)
+            commands.cluster_ps(args.quiet, args.status)
         elif args.subcmd == 'redeploy':
-            commands.app_redeploy(args.identifier, args.tag)
+            commands.cluster_redeploy(args.identifier, args.tag)
         elif args.subcmd == 'run':
-            commands.app_run(image=args.image, name=args.name, container_size=args.container_size,
-                              target_num_containers=args.target_num_containers, run_command=args.run_command,
-                              entrypoint=args.entrypoint, container_ports=args.port, container_envvars=args.env,
-                              links=args.link, autorestart=args.autorestart,
-                              autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role,
-                              sequential=args.sequential)
+            commands.cluster_run(image=args.image, name=args.name, container_size=args.container_size,
+                             target_num_containers=args.target_num_containers, run_command=args.run_command,
+                             entrypoint=args.entrypoint, container_ports=args.port, container_envvars=args.env,
+                             linked_to_cluster=args.link_cluster, linked_to_container=args.link_container,
+                             autorestart=args.autorestart,
+                             autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role,
+                             sequential=args.sequential, web_public_dns=args.web_public_dns)
         elif args.subcmd == 'scale':
-            commands.app_scale(args.identifier, args.target_num_containers)
+            commands.cluster_scale(args.identifier, args.target_num_containers)
         elif args.subcmd == 'set':
-            commands.app_set(args.autorestart, args.autoreplace, args.autodestroy, args.identifier)
+            commands.cluster_set(args.autorestart, args.autoreplace, args.autodestroy, args.identifier)
         elif args.subcmd == 'start':
-            commands.app_start(args.identifier)
+            commands.cluster_start(args.identifier)
         elif args.subcmd == 'stop':
-            commands.app_stop(args.identifier)
+            commands.cluster_stop(args.identifier)
         elif args.subcmd == 'terminate':
-            commands.app_terminate(args.identifier)
+            commands.cluster_terminate(args.identifier)
     elif args.cmd == 'container':
         if args.subcmd == 'inspect':
             commands.container_inspect(args.identifier)
@@ -87,6 +89,15 @@ def main():
             commands.container_logs(args.identifier)
         elif args.subcmd == 'ps':
             commands.container_ps(args.identifier, args.quiet, args.status)
+        elif args.subcmd == 'redeploy':
+            commands.container_redeploy(args.identifier, args.tag)
+        elif args.subcmd == 'run':
+            commands.container_run(image=args.image, name=args.name, container_size=args.container_size,
+                             run_command=args.run_command, entrypoint=args.entrypoint, container_ports=args.port,
+                             container_envvars=args.env,
+                             linked_to_cluster=args.link_cluster, linked_to_container=args.link_container,
+                             autorestart=args.autorestart,autoreplace=args.autoreplace, autodestroy=args.autodestroy,
+                             roles=args.role, web_public_dns=args.web_public_dns)
         elif args.subcmd == 'start':
             commands.container_start(args.identifier)
         elif args.subcmd == 'stop':
